@@ -2,13 +2,12 @@
 # -*- coding: utf-8 -*-
 from datetime import datetime
 
-from haystack.indexes import SearchIndex, CharField, DateTimeField
-from haystack import site
+from haystack.indexes import SearchIndex, Indexable, CharField, DateTimeField
 
 from .models import Channel
 
 
-class ChannelIndex(SearchIndex):
+class ChannelIndex(SearchIndex, Indexable):
     text = CharField(document=True, use_template=True)
     date_available = DateTimeField(model_attr='date_available')
     date_update = DateTimeField(model_attr='date_update')
@@ -16,10 +15,10 @@ class ChannelIndex(SearchIndex):
     def get_updated_field(self):
         return 'date_update'
 
-    def index_queryset(self):
-        return Channel.objects.filter(
+    def get_model(self):
+        return Channel
+
+    def index_queryset(self, using=None):
+        return self.get_model().objects.filter(
             date_available__lte=datetime.now(),
             published=True)
-
-
-site.register(Channel, ChannelIndex)
